@@ -75,10 +75,16 @@ setMethod("sds", signature(x="list"),
 		for (i in seq_along(x)) {
 			if (inherits(x[[i]], "SpatRaster")) {
 				r@pntr$add(x[[i]]@pntr, nms[i], "", "", FALSE)
-			} else if (inherits(x[[i]], "SpatRasterDataset")) {
+			} else if (inherits(x[[i]], "SpatRasterDataset")) {			
 				y <- as.list(x[[i]])
-				ynms <- names(x[[i]])
-				s <- sapply(y, function(j) r@pntr$add(j@pntr, ynms[j], "", "", FALSE))
+				ynms <- NULL
+				if (length(y) == 1) {
+					ynms <- rep(names(x)[i], length(y))
+				}
+				if (is.null(ynms)) {
+					ynms <- names(x[[i]])
+				}
+				s <- sapply(1:length(y), function(j) r@pntr$add(y[[j]]@pntr, ynms[j], "", "", FALSE))
 			} else {
 				name <- names(x[[i]])
 				cls <- paste(class(x[[i]]), collapse=", ")
@@ -90,6 +96,7 @@ setMethod("sds", signature(x="list"),
 )
 
 
+
 setMethod("sds", signature(x="array"),
 	function(x, crs="", extent=NULL) {
 		dims <- dim(x)
