@@ -12,10 +12,13 @@
 	}
 	ftmp <- unique(unlist(ftmp))
 	ftmp <- ftmp[ftmp != ""]
+	if (length(ftmp) == 0) return(ftmp)
 	pattrn <- "^spat_.*tif$"
 	i <- grep(pattrn, basename(ftmp))
 	ftmp <- ftmp[i]
-	ff <- list.files(tempdir(), pattern=pattrn, full.names=TRUE)
+	ff1 <- list.files(tempdir(), pattern=pattrn, full.names=TRUE)
+	ff2 <- list.files(terraOptions(print=FALSE)$tempdir, pattern = pattrn, full.names = TRUE)
+	ff <- unique(c(ff1, ff2))
 	i <- !(basename(ff) %in% basename(ftmp))
 	ff[i]
 
