@@ -113,8 +113,10 @@ setMethod("time", signature(x="SpatRaster"),
 		tstep <- x@pntr$timestep
 		
 		if (format != "") {
-			steps <- c("seconds", "days", "months", "years", "yearmonths")
+			steps <- c("seconds", "days", "months", "years", "yearmonths", "raw")
 			format <- match.arg(tolower(format), steps)
+			if (format == "raw") return(d)
+			
 			if ((format == "months") && (tstep == "years")) {
 				error("time", "cannot extract months from years-time")
 			} else if ((format == "years") && (tstep %in% c("months"))) {
@@ -126,29 +128,34 @@ setMethod("time", signature(x="SpatRaster"),
 			} else if ((format == "days") && (!(tstep %in% c("seconds", "days")))) {
 				error("time", "cannot extract days from this type of time data")
 			}
-			tstep <- format
 		} else if (tstep == "raw") {
 			return(d)
+		} else {
+			format = tstep
 		}
 		
 		
+		tz <- x@pntr$timezone
+		tz[tz == ""] <- "UTC"
 		d <- strptime("1970-01-01", "%Y-%m-%d", tz="UTC") + d
-		if (tstep == "seconds") {
-			tz <- x@pntr$timezone
-			if (!(tz %in% c("", "UTC"))) {
-				attr(d, "tzone") = tz
-			}
-			d
-		} else if (tstep == "days") {
-			as.Date(d)
-		} else if (tstep == "yearmonths") {
+		attr(d, "tzone") = tz
+		if (format == "seconds") {
+			return(d)
+		}
+		
+		if (format == "days") {
+		# first use format to avoid time zone trouble #1896
+		#	as.Date(format(d, "%Y-%m-%d"))
+		# above does not work with negative years. #1951	
+			as.Date(d, tz=tz)
+		} else if (format == "yearmonths") {
 			y <- as.integer(format(d, "%Y"))
 			y + (as.integer(format(d, "%m"))-1)/12
-		} else if (tstep == "months") {
+		} else if (format == "months") {
 			as.integer(format(d, "%m"))
-		} else if (tstep == "years") {
+		} else if (format == "years") {
 			as.integer(format(d, "%Y"))
-#		} else if (tstep == "yearweeks") {
+#		} else if (format == "yearweeks") {
 #			yearweek(as.Date(d))
 		} else { # ???
 			d
@@ -210,7 +217,7 @@ setMethod("time<-", signature(x="SpatRaster"),
 			if (tstep == "") stept <- "days"
 		} else if (inherits(value, "POSIXt")) {
 			if (tstep == "") stept <- "seconds"
-			tzone <- attr(value, "tzone")[1]
+			tzone <- attr(value[1], "tzone")[1]
 			if (is.null(tzone)) tzone = "UTC"
 		} else if (inherits(value, "yearmon")) {
 			value <- as.numeric(value)
