@@ -80,6 +80,13 @@ function(x, row=1, nrows=nrow(x), col=1, ncols=ncol(x), mat=FALSE, dataframe=FAL
 )
 
 
+setMethod("readValues", signature(x="SpatRasterDataset"),
+	function(x, row=1, nrows=nrow(x), col=1, ncols=ncol(x), mat=FALSE, dataframe=FALSE, ...) {
+		lapply(1:length(x), function(i) readValues(x[i], row, nrows, 1, ncols, mat=mat, dataframe=dataframe, ...))
+	}
+)
+
+
 setMethod("values", signature(x="SpatRaster"),
 function(x, mat=TRUE, dataframe=FALSE, row=1, nrows=nrow(x), col=1, ncols=ncol(x), na.rm=FALSE, ...) {
 	readStart(x)
@@ -476,8 +483,6 @@ setMethod("compareGeom", signature(x="SpatVector", y="missing"),
 		out
 	}
 )
-
-
 setMethod("all.equal", signature(target="SpatRaster", current="SpatRaster"),
 	function(target, current, maxcell=100000, ...) {
 		a <- base::all.equal(rast(target), rast(current))
@@ -507,6 +512,37 @@ setMethod("all.equal", signature(target="SpatRaster", current="SpatRaster"),
 	}
 )
 
+setMethod("all.equal", signature(target="SpatExtent", current="SpatExtent"),
+	function(target, current, ...) {
+		target == current
+	}
+)
+
+setMethod("all.equal", signature(target="SpatVector", current="SpatVector"),
+	function(target, current, ...) {
+		if (any(dim(target) != dim(current))) {
+			message("different dimensions")
+			return(FALSE)
+		}
+		if (crs(target) != crs(current)) {
+			message("different crs")
+			return(FALSE)
+		}
+		if (geomtype(target) != geomtype(current)) {
+			message("different geometry type")
+			return(FALSE)
+		}
+		if (!isTRUE(all.equal(values(target), values(current), ...))) {
+			message("different values")
+			return(FALSE)
+		}
+		if (!isTRUE(all.equal(geom(target), geom(current), ...))) {
+			message("different geometry")
+			return(FALSE)
+		}
+		TRUE
+	}
+)
 
 
 
@@ -516,12 +552,28 @@ setMethod("identical", signature(x="SpatRaster", y="SpatRaster"),
 		if (a && hasValues(x))  {
 			v <- unique(unlist(unique(x - y) ))
 			a <- identical(v, 0)
+			if (a) {
+				v <- unique(unlist(unique(is.na(x) - is.na(y)) ))
+				a <- all(v == 0)
+			}
 		}
 		a
 	}
 )
 
 
+setMethod("identical", signature(x="SpatExtent", y="SpatExtent"),
+	function(x, y) {
+		identical(as.vector(x), as.vector(y))
+	}
+)
+
+setMethod("identical", signature(x="SpatVector", y="SpatVector"),
+	function(x, y) {
+		all.equal(x, y)
+	}
+)
+
 setMethod("values", signature("SpatVector"),
 	function(x, ...) {
 		as.data.frame(x, ...)
