@@ -186,7 +186,7 @@ bool parse_ncdf_time(SpatRasterSource &s, const std::string unit, const std::str
 
 
 
-#if GDAL_VERSION_MAJOR >= 3 && GDAL_VERSION_MINOR >= 4 // && defined(IS_64_BIT)
+#if (GDAL_VERSION_MAJOR > 3) || (GDAL_VERSION_MAJOR == 3 && GDAL_VERSION_MINOR >= 4) // && defined(IS_64_BIT)
 
 
 std::vector<std::string> GetArrayNames(std::shared_ptr<GDALGroup> x, bool filter) {
@@ -358,10 +358,36 @@ bool SpatRaster::constructFromFileMulti(std::string fname, std::vector<int> subd
 		s.m_missing_value = poVar->GetNoDataValueAsDouble(&s.m_hasNA);
 	}
 
+/*
+	int ix, iy, it, iz;
+	it = 0;
+	iz = -1;
+
+// ignore dims for now
+	dims.resize(0);
+*/	
 	if (dims.size() < 2) {
 		dims = {2,1,0};
-	}
 
+/*		ix = ndim - 1;
+		iy = ix - 1;
+		if (ix == 3) {
+			iz = 1;
+			dims = {ix, iy, iz, it};
+		} else if (ndim == 2) {
+			dims = {ix, iy};
+		}
+	} else {
+		ix = dims[dims.size() - 1];
+		iy = dims[dims.size() - 2];
+		if (dims.size() == 4) {
+			iz = dims[1];
+			it = dims[0];
+		} else if (dims.size() == 4) {
+			it = dims[0];
+		}	
+*/
+	}
 	int ix = ndim - 1;
 	int iy = ix - 1;
 	int it = 0;
@@ -371,8 +397,8 @@ bool SpatRaster::constructFromFileMulti(std::string fname, std::vector<int> subd
 		dims = {ix, iy, iz, it};
 	} else if (ndim == 2) {
 		dims = {ix, iy};
-	}
-
+	}		
+	
 	//Rcpp::Rcout << ix << ", " << iy << ", " << iz << ", " << it << std::endl;
 	
 	SpatExtent e;
