@@ -125,7 +125,7 @@ std::vector<int> get_date(SpatTime_t x) {
 }
 
 
-
+/*
 std::vector<std::string> splitstr(std::string s, std::string delimiter){
 	std::vector<std::string> out;
 	size_t pos = 0;
@@ -136,6 +136,7 @@ std::vector<std::string> splitstr(std::string s, std::string delimiter){
 	out.push_back(s.substr(0, pos));
 	return out;
 }
+*/
 
 void replace_one_char(std::string& s, char from, char to) {
 	for (size_t i = 0; i < s.size(); i++) {
@@ -167,17 +168,17 @@ std::vector<int> getymd(std::string s) {
 	std::vector<std::string> x;
 	std::vector<std::string> y;
 	if (ncolon > 0) {
-		x = splitstr(s, " ");
+		x = strsplit(s, " ");
 		s = x[0];
 		if (x.size() > 1) {
 			x[1].erase(std::remove(x[1].begin(), x[1].end(), 'z'), x[1].end());
-			y = splitstr(x[1], ":");
+			y = strsplit(x[1], ":");
 		}
 	}
 
 	size_t ndash = std::count(s.begin(), s.end(), '-');
 	if (ndash == 2) {
-		x = splitstr(s, "-");
+		x = strsplit(s, "-");
 	}
 	x.insert(x.end(), y.begin(), y.end() );
 	std::vector<int> out(x.size());
@@ -246,10 +247,8 @@ SpatTime_t get_time_noleap(int syear, int smonth, int sday, int shour, int smin,
 	static const int md[13] =  {0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365 };
 
 	// set start to beginning of year 
-	double s = ssec + smin * 60 + shour * 3600 + (sday-1) * 24 * 3600;
-	for (int i=0; i < smonth; i++) {
-		s += (md[i] * 24 * 3600);
-	}
+	double s = ssec + smin * 60 + shour * 3600 + (sday-1) * 86400;
+	s += md[smonth-1] * 86400;
 
 	double ndays;
 	if (step == "hours") {
@@ -267,12 +266,17 @@ SpatTime_t get_time_noleap(int syear, int smonth, int sday, int shour, int smin,
 
 	int year = ndays / 365;
 	double rem = ndays - year * 365;
+	if (rem < 0) {
+		year--;
+		rem = 365 + rem;
+	}
 	int month;
 	for (month=1; month<13; month++) {
 		if (rem < md[month]) {
 			break;
 		}
 	}
+
 	rem -= md[month-1];
 	int day = rem;
 	rem -= day;
@@ -292,7 +296,8 @@ SpatTime_t get_time_noleap(int syear, int smonth, int sday, int shour, int smin,
 SpatTime_t get_time_360(int syear, int smonth, int sday, int shour, int smin, int ssec, double n, std::string step) {
 
 	// set start to beginning of year 
-	double s = ssec + smin * 60 + shour * 3600 + (sday-1) * 24 * 3600 + (smonth-1) * 30;
+	int sdays = (smonth-1) * 30 + (sday-1);
+	double s = ssec + smin * 60 + shour * 3600 + sdays * 86400;
 
 	double ndays;
 	if (step == "hours") {
@@ -310,6 +315,12 @@ SpatTime_t get_time_360(int syear, int smonth, int sday, int shour, int smin, in
 
 	int year = ndays / 360;
 	double rem = ndays - year * 360;
+
+	if (rem < 0) {
+		year--;
+		rem = 365 + rem;
+	}
+
 	int month = rem / 30;
 	rem -= month * 30;
 	month++;
