@@ -28,6 +28,7 @@
 
 #include <map>
 #include <algorithm>
+#include <unordered_map>
 
 
 bool haveFun(std::string fun);
@@ -49,7 +50,7 @@ std::vector<T> flatten(const std::vector<std::vector<T>>& v) {
 }
 
 
-static inline double interpolate(double x, double y1, double y2, unsigned x1, unsigned x2) {
+static inline double interpolate(double x, double y1, double y2, double x1, double x2) {
 	double denom = (x2-x1);
 	return y1 + (x-x1) * (y2-y1)/denom;
 }
@@ -81,13 +82,13 @@ static inline std::vector<double> vquantile(std::vector<double> v, const std::ve
 	std::vector<double> q(pn);
 
     for (size_t i = 0; i < pn; ++i) {
-		double x = probs[i] * (n-1);
-		unsigned x1 = std::floor(x);
-		unsigned x2 = std::ceil(x);
+		double x = probs[i] * (double)(n-1);
+		size_t x1 = (size_t)std::floor(x);
+		size_t x2 = (size_t)std::ceil(x);
 		if (x1 == x2) {
 			q[i] = v[x1];
 		} else {
-			q[i] = interpolate(x, v[x1], v[x2], x1, x2);
+			q[i] = interpolate(x, v[x1], v[x2], (double)x1, (double)x2);
 		}
     }
     return q;
@@ -149,6 +150,7 @@ T vmedian(std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vsum(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0];
 	if (narm) {		
 		for (size_t i=1; i<v.size(); i++) {
@@ -176,6 +178,7 @@ T vsum(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vsum2(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0] * v[0];
 	if (narm) {		
 		for (size_t i=1; i<v.size(); i++) {
@@ -204,6 +207,7 @@ T vsum2(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vprod(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0];
 	if (narm) {
 		for (size_t i=1; i<v.size(); i++) {
@@ -232,6 +236,7 @@ T vprod(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 double vmean(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NAN;
 	double x = 0;
 	unsigned d = 0;
 	if (narm) {
@@ -302,6 +307,7 @@ double vsdpop(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vmin(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0];
 	if (narm) {
 		for (size_t i=1; i<v.size(); i++) {
@@ -329,6 +335,7 @@ T vmin(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vfirst(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	if (narm) {
 		for (size_t i=0; i<v.size(); i++) {
 			if (!is_NA(v[i])) {
@@ -342,6 +349,7 @@ T vfirst(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vmax(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0];
 	if (narm) {
 		for (size_t i=1; i<v.size(); i++) {
@@ -384,6 +392,7 @@ double vwhich(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vwhichmin(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0];
 	T out;
 	if (is_NA(x)) {
@@ -426,6 +435,7 @@ T vwhichmin(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vwhichmax(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = v[0];
 	T out;
 	if (is_NA(x)) {
@@ -470,6 +480,7 @@ T vwhichmax(const std::vector<T>& v, bool narm) {
 // won't work with bool values (nodata == 0)
 template <typename T>
 T vall(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x;
 	if (narm) {
 		x = NA<T>::value;
@@ -500,6 +511,7 @@ T vall(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 T vany(const std::vector<T>& v, bool narm) {
+	if (v.empty()) return NA<T>::value;
 	T x = NA<T>::value;
 	x = 0;
 	if (narm) {
@@ -528,7 +540,9 @@ T vany(const std::vector<T>& v, bool narm) {
 
 template <typename T>
 std::vector<T> vrange(const std::vector<T>& v, bool narm) {
-	
+	if (v.empty()) {
+		return std::vector<T>{ NA<T>::value, NA<T>::value };
+	}
 	std::vector<T> x = { v[0], v[0] };
 
 	if (narm) {
